@@ -83,10 +83,10 @@ def main():
         #    tmp = line.strip('\n').split('reset\\_value')
         #    msg = tmp[0] + '\n\\\\\n' + 'reset\\_value' + tmp[1] + '\n' + '\\\\\n'
         #    fo.write(msg)
-        elif line.find('地址偏移') >= 0 and line.find('默认值') >= 0:
-            tmp = line.strip('\n').split('默认值')
-            msg = tmp[0] + '\n\\\\\n' + '默认值' + tmp[1] + '\n' + '\\\\\n'
-            fo.write(msg)
+        #elif line.find('地址偏移') >= 0 and line.find('默认值') >= 0:
+        #    tmp = line.strip('\n').split('默认值')
+        #    msg = tmp[0] + '\n\\\\\n' + '默认值' + tmp[1] + '\n' + '\\\\\n'
+        #    fo.write(msg)
         elif line.startswith('\\usepackage{xeCJK}'):
             msg = line
             #msg += '\\usepackage{hyperref}\n'
@@ -103,6 +103,11 @@ def main():
             fo.write(line.replace('&', '\\&'))
         elif line.find('\&nbsp;') >= 0  and table_start == 1:
             fo.write(line.replace('\&nbsp;', ''))
+        elif line.find('‣') >= 0:
+            if table_start == 1:
+                fo.write(line.replace('‣', '\\newline'))
+            else:
+                fo.write(line.replace('‣', '\\\\'))
         else:
             fo.write(line)
         if not line:
